# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class NetconfClient(Base):
	"""The NetconfClient class encapsulates a user managed netconfClient node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the NetconfClient property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'netconfClient'

	def __init__(self, parent):
		super(NetconfClient, self).__init__(parent)

	@property
	def CommandSnippetsData(self):
		"""An instance of the CommandSnippetsData class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.commandsnippetsdata.CommandSnippetsData)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.commandsnippetsdata import CommandSnippetsData
		return CommandSnippetsData(self)._select()

	@property
	def LearnedInfo(self):
		"""An instance of the LearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo.LearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo import LearnedInfo
		return LearnedInfo(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def CapabilitiesBase1Dot0(self):
		"""This specifies whether base1.0 support should be advertised in Capabilities.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesBase1Dot0')

	@property
	def CapabilitiesBase1Dot1(self):
		"""This specifies whether base1.1 support should be advertised in Capabilities.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesBase1Dot1')

	@property
	def CapabilitiesCandidate(self):
		"""This specifies whether Netconf Client supports capability candidate to make changes into an intermediate candidate database. Normally this is preferred over writable-running.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesCandidate')

	@property
	def CapabilitiesConfirmedCommit(self):
		"""This specifies whether Netconf Client supports capability confirmed-commit to specify ability to commit a group of commands or none as a batch.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesConfirmedCommit')

	@property
	def CapabilitiesInterleave(self):
		"""This specifies whether Netconf Client supports capability interleave to interleave notifications and responses.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesInterleave')

	@property
	def CapabilitiesNotification(self):
		"""This specifies whether Netconf Client supports capability notification to aynchronously handle notifications from Netconf server device connected to.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesNotification')

	@property
	def CapabilitiesRollbackOnError(self):
		"""This specifies whether Netconf Client supports capability rollback to rollback partial changes make changes on detection of error during validate or commit.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesRollbackOnError')

	@property
	def CapabilitiesStartup(self):
		"""This specifies whether Netconf Client supports capability startup to make changes in config persistent on device restart.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesStartup')

	@property
	def CapabilitiesUrl(self):
		"""This specifies whether Netconf Client supports capability url to specify netconf commands using url.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesUrl')

	@property
	def CapabilitiesValidate(self):
		"""This specifies whether Netconf Client supports capability validate to specify ability to validate a netconf command prior to commit.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesValidate')

	@property
	def CapabilitiesWritableRunning(self):
		"""This specifies whether Netconf Client supports capability writable-running to directly modify running config.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesWritableRunning')

	@property
	def CapabilitiesXpath(self):
		"""This specifies whether Netconf Client supports capability xpath to specify netconf commands and filters using xpath extensions.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('capabilitiesXpath')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DecryptedCapture(self):
		"""DEPRECATED This specifies whether SSH packets for this session will be captured and stored on client in decrypted form.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('decryptedCapture')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnablePassphrase(self):
		"""DEPRECATED If the Private Key was passphrase protected, this should be enabled to allow configuration of passphrase used.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enablePassphrase')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def FetchSchemaInfo(self):
		"""DEPRECATED This specifies whether a get-schema operation will be performed after capability exchange

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('fetchSchemaInfo')

	@property
	def LogCleanUpOption(self):
		"""DEPRECATED Debug Log Clean Up

		Returns:
			str(clean|notClean)
		"""
		return self._get_attribute('logCleanUpOption')
	@LogCleanUpOption.setter
	def LogCleanUpOption(self, value):
		self._set_attribute('logCleanUpOption', value)

	@property
	def LogFileAge(self):
		"""DEPRECATED This field determines how old logs to be deleted.

		Returns:
			number
		"""
		return self._get_attribute('logFileAge')
	@LogFileAge.setter
	def LogFileAge(self, value):
		self._set_attribute('logFileAge', value)

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NetconfSessionState(self):
		"""DEPRECATED Shows the current state of the Netconf SSH Session. None - Not started. Initialized - Configuration has reached the port and TCP connect is on-going. Connecting - SSH Connect is in process. Authenticating - The SSH session is authenticating with the DUT using user/password or Key-based authentication. Open Channel - SSH session is established and SSH Channel is being opened on which data will be sent. Requesting Subsystem - Netconf Subsystem is being requested on top of SSH channel. Ready - The SSH session is in Ready state and waiting for Netconf data to be exchanged. Note that this does not mean that NETCONF is in Up state. That is reached only after Netconf Capabilities are negotiated and there is at least one matching Netconf version (1.0 or 1.1) supported on both client and server. Reconnecting - The TCP connection is broken with DUT and the client is trying to reconnect via TCP with the server.

		Returns:
			list(str[authenticating|connecting|initialized|none|openingChannel|ready|reconnecting|requestingSubsystem])
		"""
		return self._get_attribute('netconfSessionState')

	@property
	def NumberOfCommandSnippetsPerClient(self):
		"""DEPRECATED Number of Command Snippets per client.Maximum 100 are allowed per client.

		Returns:
			number
		"""
		return self._get_attribute('numberOfCommandSnippetsPerClient')
	@NumberOfCommandSnippetsPerClient.setter
	def NumberOfCommandSnippetsPerClient(self, value):
		self._set_attribute('numberOfCommandSnippetsPerClient', value)

	@property
	def OutputDirectory(self):
		"""DEPRECATED Location of Directory in Client where the decrypted capture, if enabled, and server replies, if enabled, will be stored.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('outputDirectory')

	@property
	def Passphrase(self):
		"""DEPRECATED The passphrase with which the Private Key was additionally protected during generation. For multiple clients and assymetric passphrases( which cannot be expressed easily as a pattern) please explore File option in Master Row Pattern Editor by putting the file namesin a .csv and pulling those values into the column cells.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('passphrase')

	@property
	def Password(self):
		"""DEPRECATED Password for Username/Password mode.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('password')

	@property
	def PortNumber(self):
		"""DEPRECATED The TCP Port Number the Netconf Server is listening on to which to connect.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('portNumber')

	@property
	def PrivateKeyDirectory(self):
		"""DEPRECATED Directory containing Private Key file for this session.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('privateKeyDirectory')

	@property
	def PrivateKeyFileName(self):
		"""DEPRECATED File containing Private Key.(e.g. generated using ssh_keygen) . For multiple clients and assymetric key file names( which cannot be expressed easily as a pattern) please explore File option in Master Row Pattern Editor by putting the file namesin a .csv and pulling those values into the column cells.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('privateKeyFileName')

	@property
	def SaveReplyXML(self):
		"""DEPRECATED If this is enabled, Hellos and replies to commands sent via Command Snippets or global command (such as 'get') by the Netconf Server will be stored in the Output Directoryin current run folder/Replies. Any RPC errors recieved will be stored in a separate Error directory for convenience of debugging error scenarios.This option can be enabled even when a session is already up in which case the replies will be saved from that point of time.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('saveReplyXML')

	@property
	def SchemaOutputDirectory(self):
		"""DEPRECATED Location of Directory in Client where the retrieved modules will be stored.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('schemaOutputDirectory')

	@property
	def SendCloseOnStop(self):
		"""DEPRECATED This specifies whether a <close-session> message will be sent on stopping this client

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sendCloseOnStop')

	@property
	def ServerIpv4Address(self):
		"""DEPRECATED Specify the IPv4 address of the DUT to which the Netconf Server should connect.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('serverIpv4Address')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def SshAuthenticationMechanism(self):
		"""DEPRECATED The authentication mechanism for connecting to Netconf Server.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sshAuthenticationMechanism')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def UserName(self):
		"""DEPRECATED Username for Username/Password mode and also used for Key-based Authentication as the username.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('userName')

	def update(self, ConnectedVia=None, LogCleanUpOption=None, LogFileAge=None, Multiplier=None, Name=None, NumberOfCommandSnippetsPerClient=None, StackedLayers=None):
		"""Updates a child instance of netconfClient on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			LogCleanUpOption (str(clean|notClean)): Debug Log Clean Up
			LogFileAge (number): This field determines how old logs to be deleted.
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberOfCommandSnippetsPerClient (number): Number of Command Snippets per client.Maximum 100 are allowed per client.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, LogCleanUpOption=None, LogFileAge=None, Multiplier=None, Name=None, NumberOfCommandSnippetsPerClient=None, StackedLayers=None):
		"""Adds a new netconfClient node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			LogCleanUpOption (str(clean|notClean)): Debug Log Clean Up
			LogFileAge (number): This field determines how old logs to be deleted.
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NumberOfCommandSnippetsPerClient (number): Number of Command Snippets per client.Maximum 100 are allowed per client.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved netconfClient data using find and the newly added netconfClient data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the netconfClient data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, Errors=None, LogCleanUpOption=None, LogFileAge=None, Multiplier=None, Name=None, NetconfSessionState=None, NumberOfCommandSnippetsPerClient=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves netconfClient data from the server.

		All named parameters support regex and can be used to selectively retrieve netconfClient data from the server.
		By default the find method takes no parameters and will retrieve all netconfClient data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			LogCleanUpOption (str(clean|notClean)): Debug Log Clean Up
			LogFileAge (number): This field determines how old logs to be deleted.
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NetconfSessionState (list(str[authenticating|connecting|initialized|none|openingChannel|ready|reconnecting|requestingSubsystem])): Shows the current state of the Netconf SSH Session. None - Not started. Initialized - Configuration has reached the port and TCP connect is on-going. Connecting - SSH Connect is in process. Authenticating - The SSH session is authenticating with the DUT using user/password or Key-based authentication. Open Channel - SSH session is established and SSH Channel is being opened on which data will be sent. Requesting Subsystem - Netconf Subsystem is being requested on top of SSH channel. Ready - The SSH session is in Ready state and waiting for Netconf data to be exchanged. Note that this does not mean that NETCONF is in Up state. That is reached only after Netconf Capabilities are negotiated and there is at least one matching Netconf version (1.0 or 1.1) supported on both client and server. Reconnecting - The TCP connection is broken with DUT and the client is trying to reconnect via TCP with the server.
			NumberOfCommandSnippetsPerClient (number): Number of Command Snippets per client.Maximum 100 are allowed per client.
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching netconfClient data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of netconfClient data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the netconfClient data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, CapabilitiesBase1Dot0=None, CapabilitiesBase1Dot1=None, CapabilitiesCandidate=None, CapabilitiesConfirmedCommit=None, CapabilitiesInterleave=None, CapabilitiesNotification=None, CapabilitiesRollbackOnError=None, CapabilitiesStartup=None, CapabilitiesUrl=None, CapabilitiesValidate=None, CapabilitiesWritableRunning=None, CapabilitiesXpath=None, DecryptedCapture=None, EnablePassphrase=None, FetchSchemaInfo=None, OutputDirectory=None, Passphrase=None, Password=None, PortNumber=None, PrivateKeyDirectory=None, PrivateKeyFileName=None, SaveReplyXML=None, SchemaOutputDirectory=None, SendCloseOnStop=None, ServerIpv4Address=None, SshAuthenticationMechanism=None, UserName=None):
		"""Base class infrastructure that gets a list of netconfClient device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			CapabilitiesBase1Dot0 (str): optional regex of capabilitiesBase1Dot0
			CapabilitiesBase1Dot1 (str): optional regex of capabilitiesBase1Dot1
			CapabilitiesCandidate (str): optional regex of capabilitiesCandidate
			CapabilitiesConfirmedCommit (str): optional regex of capabilitiesConfirmedCommit
			CapabilitiesInterleave (str): optional regex of capabilitiesInterleave
			CapabilitiesNotification (str): optional regex of capabilitiesNotification
			CapabilitiesRollbackOnError (str): optional regex of capabilitiesRollbackOnError
			CapabilitiesStartup (str): optional regex of capabilitiesStartup
			CapabilitiesUrl (str): optional regex of capabilitiesUrl
			CapabilitiesValidate (str): optional regex of capabilitiesValidate
			CapabilitiesWritableRunning (str): optional regex of capabilitiesWritableRunning
			CapabilitiesXpath (str): optional regex of capabilitiesXpath
			DecryptedCapture (str): optional regex of decryptedCapture
			EnablePassphrase (str): optional regex of enablePassphrase
			FetchSchemaInfo (str): optional regex of fetchSchemaInfo
			OutputDirectory (str): optional regex of outputDirectory
			Passphrase (str): optional regex of passphrase
			Password (str): optional regex of password
			PortNumber (str): optional regex of portNumber
			PrivateKeyDirectory (str): optional regex of privateKeyDirectory
			PrivateKeyFileName (str): optional regex of privateKeyFileName
			SaveReplyXML (str): optional regex of saveReplyXML
			SchemaOutputDirectory (str): optional regex of schemaOutputDirectory
			SendCloseOnStop (str): optional regex of sendCloseOnStop
			ServerIpv4Address (str): optional regex of serverIpv4Address
			SshAuthenticationMechanism (str): optional regex of sshAuthenticationMechanism
			UserName (str): optional regex of userName

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def ClearAllLearnedSchemaInfo(self, *args, **kwargs):
		"""Executes the clearAllLearnedSchemaInfo operation on the server.

		Clear All Learned Schema Info.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		clearAllLearnedSchemaInfo()

		clearAllLearnedSchemaInfo(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		clearAllLearnedSchemaInfo(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearAllLearnedSchemaInfo', payload=payload, response_object=None)

	def ClearAllLearnedSchemaInfoInClient(self, *args, **kwargs):
		"""Executes the clearAllLearnedSchemaInfoInClient operation on the server.

		Clears ALL learned info.

		clearAllLearnedSchemaInfoInClient(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearAllLearnedSchemaInfoInClient', payload=payload, response_object=None)

	def ExecuteCommandGet(self, *args, **kwargs):
		"""Executes the executeCommandGet operation on the server.

		Send get command to DUT if the Netconf session is in established/ready state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		executeCommandGet()

		executeCommandGet(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		executeCommandGet(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		executeCommandGet(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the device group.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('executeCommandGet', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def GetDecryptedCapture(self, *args, **kwargs):
		"""Executes the getDecryptedCapture operation on the server.

		If Enable Capture is enabled, this will fetch and open the decrypted capture for selected sessions.

		getDecryptedCapture(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the device group.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getDecryptedCapture', payload=payload, response_object=None)

	def GetLearnedSchemaInfo(self, *args, **kwargs):
		"""Executes the getLearnedSchemaInfo operation on the server.

		Get Learned Schema Info.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		getLearnedSchemaInfo()

		getLearnedSchemaInfo(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		getLearnedSchemaInfo(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		getLearnedSchemaInfo(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getLearnedSchemaInfo', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class RouteRange(Base):
	"""The RouteRange class encapsulates a user managed routeRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the RouteRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'routeRange'

	def __init__(self, parent):
		super(RouteRange, self).__init__(parent)

	@property
	def Enabled(self):
		"""Enables the selected route range.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def FirstRoute(self):
		"""The IPv6 address of the first route/network to be generated for this RIPng route range.

		Returns:
			str
		"""
		return self._get_attribute('firstRoute')
	@FirstRoute.setter
	def FirstRoute(self, value):
		self._set_attribute('firstRoute', value)

	@property
	def MaskWidth(self):
		"""The network mask to be used when generating routes This value indicates the number of bits, counting from the MSB (at the left end), that will comprise the network part of the IPv6 address. The remainder of the address will indicate the host part of the address. The default mask width is 64 bits.

		Returns:
			number
		"""
		return self._get_attribute('maskWidth')
	@MaskWidth.setter
	def MaskWidth(self, value):
		self._set_attribute('maskWidth', value)

	@property
	def Metric(self):
		"""The current metric cost to reach the destination. A value between 0 and 15. A value of 16 indicates that the destination is unreachable. (The RIPng Interface Metric is added to this value.)

		Returns:
			number
		"""
		return self._get_attribute('metric')
	@Metric.setter
	def Metric(self, value):
		self._set_attribute('metric', value)

	@property
	def NextHop(self):
		"""(For use in the Next Hop RTE.)The link-local IPv6 address of the next hop router. The value 0:0:0:0:0:0:0:0 indicates that the next hop router should be the originator of the RIPng route advertisement. (This router is the Next Hop.)

		Returns:
			str
		"""
		return self._get_attribute('nextHop')
	@NextHop.setter
	def NextHop(self, value):
		self._set_attribute('nextHop', value)

	@property
	def NumberOfRoute(self):
		"""The total number of routes to be included in this route range.

		Returns:
			number
		"""
		return self._get_attribute('numberOfRoute')
	@NumberOfRoute.setter
	def NumberOfRoute(self, value):
		self._set_attribute('numberOfRoute', value)

	@property
	def RouteTag(self):
		"""A route attribute advertised with a route: internal vs. external. For external routes, the route tag can be the AS from which the routes were learned or an arbitrary, assigned integer value.

		Returns:
			number
		"""
		return self._get_attribute('routeTag')
	@RouteTag.setter
	def RouteTag(self, value):
		self._set_attribute('routeTag', value)

	@property
	def Step(self):
		"""The increment step value to be used when creating additional routes/network addresses.

		Returns:
			number
		"""
		return self._get_attribute('step')
	@Step.setter
	def Step(self, value):
		self._set_attribute('step', value)

	def update(self, Enabled=None, FirstRoute=None, MaskWidth=None, Metric=None, NextHop=None, NumberOfRoute=None, RouteTag=None, Step=None):
		"""Updates a child instance of routeRange on the server.

		Args:
			Enabled (bool): Enables the selected route range.
			FirstRoute (str): The IPv6 address of the first route/network to be generated for this RIPng route range.
			MaskWidth (number): The network mask to be used when generating routes This value indicates the number of bits, counting from the MSB (at the left end), that will comprise the network part of the IPv6 address. The remainder of the address will indicate the host part of the address. The default mask width is 64 bits.
			Metric (number): The current metric cost to reach the destination. A value between 0 and 15. A value of 16 indicates that the destination is unreachable. (The RIPng Interface Metric is added to this value.)
			NextHop (str): (For use in the Next Hop RTE.)The link-local IPv6 address of the next hop router. The value 0:0:0:0:0:0:0:0 indicates that the next hop router should be the originator of the RIPng route advertisement. (This router is the Next Hop.)
			NumberOfRoute (number): The total number of routes to be included in this route range.
			RouteTag (number): A route attribute advertised with a route: internal vs. external. For external routes, the route tag can be the AS from which the routes were learned or an arbitrary, assigned integer value.
			Step (number): The increment step value to be used when creating additional routes/network addresses.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Enabled=None, FirstRoute=None, MaskWidth=None, Metric=None, NextHop=None, NumberOfRoute=None, RouteTag=None, Step=None):
		"""Adds a new routeRange node on the server and retrieves it in this instance.

		Args:
			Enabled (bool): Enables the selected route range.
			FirstRoute (str): The IPv6 address of the first route/network to be generated for this RIPng route range.
			MaskWidth (number): The network mask to be used when generating routes This value indicates the number of bits, counting from the MSB (at the left end), that will comprise the network part of the IPv6 address. The remainder of the address will indicate the host part of the address. The default mask width is 64 bits.
			Metric (number): The current metric cost to reach the destination. A value between 0 and 15. A value of 16 indicates that the destination is unreachable. (The RIPng Interface Metric is added to this value.)
			NextHop (str): (For use in the Next Hop RTE.)The link-local IPv6 address of the next hop router. The value 0:0:0:0:0:0:0:0 indicates that the next hop router should be the originator of the RIPng route advertisement. (This router is the Next Hop.)
			NumberOfRoute (number): The total number of routes to be included in this route range.
			RouteTag (number): A route attribute advertised with a route: internal vs. external. For external routes, the route tag can be the AS from which the routes were learned or an arbitrary, assigned integer value.
			Step (number): The increment step value to be used when creating additional routes/network addresses.

		Returns:
			self: This instance with all currently retrieved routeRange data using find and the newly added routeRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the routeRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Enabled=None, FirstRoute=None, MaskWidth=None, Metric=None, NextHop=None, NumberOfRoute=None, RouteTag=None, Step=None):
		"""Finds and retrieves routeRange data from the server.

		All named parameters support regex and can be used to selectively retrieve routeRange data from the server.
		By default the find method takes no parameters and will retrieve all routeRange data from the server.

		Args:
			Enabled (bool): Enables the selected route range.
			FirstRoute (str): The IPv6 address of the first route/network to be generated for this RIPng route range.
			MaskWidth (number): The network mask to be used when generating routes This value indicates the number of bits, counting from the MSB (at the left end), that will comprise the network part of the IPv6 address. The remainder of the address will indicate the host part of the address. The default mask width is 64 bits.
			Metric (number): The current metric cost to reach the destination. A value between 0 and 15. A value of 16 indicates that the destination is unreachable. (The RIPng Interface Metric is added to this value.)
			NextHop (str): (For use in the Next Hop RTE.)The link-local IPv6 address of the next hop router. The value 0:0:0:0:0:0:0:0 indicates that the next hop router should be the originator of the RIPng route advertisement. (This router is the Next Hop.)
			NumberOfRoute (number): The total number of routes to be included in this route range.
			RouteTag (number): A route attribute advertised with a route: internal vs. external. For external routes, the route tag can be the AS from which the routes were learned or an arbitrary, assigned integer value.
			Step (number): The increment step value to be used when creating additional routes/network addresses.

		Returns:
			self: This instance with matching routeRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of routeRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the routeRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SwitchActionV131LearnedInfo(Base):
	"""The SwitchActionV131LearnedInfo class encapsulates a system managed switchActionV131LearnedInfo node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SwitchActionV131LearnedInfo property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'switchActionV131LearnedInfo'

	def __init__(self, parent):
		super(SwitchActionV131LearnedInfo, self).__init__(parent)

	@property
	def ActionType(self):
		"""This describes the action associated with the flow entry.

		Returns:
			str
		"""
		return self._get_attribute('actionType')

	@property
	def ArpDstHwAddress(self):
		"""This describes the target hardware address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpDstHwAddress')

	@property
	def ArpDstIpv4Address(self):
		"""This describes the target IPv4 address in the ARP payload.

		Returns:
			number
		"""
		return self._get_attribute('arpDstIpv4Address')

	@property
	def ArpOpcode(self):
		"""This describes the ARP opcode.

		Returns:
			number
		"""
		return self._get_attribute('arpOpcode')

	@property
	def ArpSrcHwAddress(self):
		"""This describes the source hardware address in the ARP payload.

		Returns:
			str
		"""
		return self._get_attribute('arpSrcHwAddress')

	@property
	def ArpSrcIpv4Address(self):
		"""This describes the source IPv4 address in the ARP payload.

		Returns:
			number
		"""
		return self._get_attribute('arpSrcIpv4Address')

	@property
	def EthernetDestination(self):
		"""This describes the destination address of the Ethernet port.

		Returns:
			str
		"""
		return self._get_attribute('ethernetDestination')

	@property
	def EthernetSource(self):
		"""This describes the source address of the Ethernet port.

		Returns:
			str
		"""
		return self._get_attribute('ethernetSource')

	@property
	def EthernetType(self):
		"""This describes the Ethernet type of the flow match.

		Returns:
			str
		"""
		return self._get_attribute('ethernetType')

	@property
	def Experimenter(self):
		"""This describes the unique Experimenter identifier. The default value is 1.

		Returns:
			number
		"""
		return self._get_attribute('experimenter')

	@property
	def ExperimenterData(self):
		"""This describes the data of the Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('experimenterData')

	@property
	def ExperimenterDatalength(self):
		"""This describes the data length of the Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('experimenterDatalength')

	@property
	def GroupId(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('groupId')

	@property
	def Icmpv4Code(self):
		"""This describes the ICMP code.

		Returns:
			number
		"""
		return self._get_attribute('icmpv4Code')

	@property
	def Icmpv4Type(self):
		"""This describes the ICMP type.

		Returns:
			number
		"""
		return self._get_attribute('icmpv4Type')

	@property
	def Icmpv6Code(self):
		"""This describes the ICMPv6 code.

		Returns:
			number
		"""
		return self._get_attribute('icmpv6Code')

	@property
	def Icmpv6Type(self):
		"""This describes the ICMPv6 type.

		Returns:
			number
		"""
		return self._get_attribute('icmpv6Type')

	@property
	def IpDscp(self):
		"""This describes the IP DSCP value for advertising.

		Returns:
			str
		"""
		return self._get_attribute('ipDscp')

	@property
	def IpEcn(self):
		"""This describes the ECN bits of the IP header.

		Returns:
			number
		"""
		return self._get_attribute('ipEcn')

	@property
	def IpProtocol(self):
		"""This describes the IP Protocol used.

		Returns:
			number
		"""
		return self._get_attribute('ipProtocol')

	@property
	def Ipv4Destination(self):
		"""This describes the IPv4 destination address.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Destination')

	@property
	def Ipv4Source(self):
		"""This describes the IPv4 source address.

		Returns:
			str
		"""
		return self._get_attribute('ipv4Source')

	@property
	def Ipv6Destination(self):
		"""This describes the IPv6 destination address.

		Returns:
			str
		"""
		return self._get_attribute('ipv6Destination')

	@property
	def Ipv6ExtHeader(self):
		"""This describes the IPv6 Extension Header pseudo-field.

		Returns:
			number
		"""
		return self._get_attribute('ipv6ExtHeader')

	@property
	def Ipv6FlowLabel(self):
		"""This describes the IPv6 Flow label.

		Returns:
			number
		"""
		return self._get_attribute('ipv6FlowLabel')

	@property
	def Ipv6NdSll(self):
		"""This describes the source link-layer address option in an IPv6 Neighbor Discovery message.

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdSll')

	@property
	def Ipv6NdTarget(self):
		"""This describes the target address in an IPv6 Neighbor Discovery message.

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdTarget')

	@property
	def Ipv6NdTll(self):
		"""This describes the target link-layer address option in an IPv6 Neighbor Discovery message

		Returns:
			str
		"""
		return self._get_attribute('ipv6NdTll')

	@property
	def Ipv6Source(self):
		"""This describes the IPv6 source address.

		Returns:
			str
		"""
		return self._get_attribute('ipv6Source')

	@property
	def MaxByteLength(self):
		"""This describes the maximum amount of data from a packet that should be sent when the port is OFPP_CONTROLLER.

		Returns:
			number
		"""
		return self._get_attribute('maxByteLength')

	@property
	def MplsBos(self):
		"""This describes the BoS bit in the first MPLS shim header.

		Returns:
			number
		"""
		return self._get_attribute('mplsBos')

	@property
	def MplsLabel(self):
		"""This describes the LABEL in the first MPLS shim header.

		Returns:
			number
		"""
		return self._get_attribute('mplsLabel')

	@property
	def MplsTc(self):
		"""This describes the TC in the first MPLS shim header.

		Returns:
			number
		"""
		return self._get_attribute('mplsTc')

	@property
	def MplsTtl(self):
		"""This replaces the existing MPLS TTL. Only applies to packets with an existing MPLS shim header.

		Returns:
			number
		"""
		return self._get_attribute('mplsTtl')

	@property
	def NetworkTtl(self):
		"""This describes the IP TTL.

		Returns:
			number
		"""
		return self._get_attribute('networkTtl')

	@property
	def OutputPort(self):
		"""This describes the out port value. It requires matching entries to include this as an output port.

		Returns:
			number
		"""
		return self._get_attribute('outputPort')

	@property
	def OutputPortType(self):
		"""This describes the Output Port Type for this Flow Range

		Returns:
			str
		"""
		return self._get_attribute('outputPortType')

	@property
	def PbbIsid(self):
		"""This describes the I-SID in the first PBB service instance tag.

		Returns:
			number
		"""
		return self._get_attribute('pbbIsid')

	@property
	def QueueId(self):
		"""This describes the queue of the port in which the packet should be enqueued.

		Returns:
			number
		"""
		return self._get_attribute('queueId')

	@property
	def SctpDestination(self):
		"""This describes the SCTP target port.

		Returns:
			number
		"""
		return self._get_attribute('sctpDestination')

	@property
	def SctpSource(self):
		"""This describes the SCTP source port.

		Returns:
			number
		"""
		return self._get_attribute('sctpSource')

	@property
	def TcpDestination(self):
		"""This describes the TCP destination address.

		Returns:
			number
		"""
		return self._get_attribute('tcpDestination')

	@property
	def TcpSource(self):
		"""This describes the TCP source address.

		Returns:
			number
		"""
		return self._get_attribute('tcpSource')

	@property
	def TunnelId(self):
		"""This describes the unique identifier used for the Tunnel.

		Returns:
			str
		"""
		return self._get_attribute('tunnelId')

	@property
	def UdpDestination(self):
		"""This describes the UDP destination port.

		Returns:
			number
		"""
		return self._get_attribute('udpDestination')

	@property
	def UdpSource(self):
		"""This describes the UDP source port.

		Returns:
			number
		"""
		return self._get_attribute('udpSource')

	@property
	def VlanId(self):
		"""This describes the unique VLAN Identifier.

		Returns:
			number
		"""
		return self._get_attribute('vlanId')

	@property
	def VlanPriority(self):
		"""This describes the User Priority for this VLAN.

		Returns:
			number
		"""
		return self._get_attribute('vlanPriority')

	def find(self, ActionType=None, ArpDstHwAddress=None, ArpDstIpv4Address=None, ArpOpcode=None, ArpSrcHwAddress=None, ArpSrcIpv4Address=None, EthernetDestination=None, EthernetSource=None, EthernetType=None, Experimenter=None, ExperimenterData=None, ExperimenterDatalength=None, GroupId=None, Icmpv4Code=None, Icmpv4Type=None, Icmpv6Code=None, Icmpv6Type=None, IpDscp=None, IpEcn=None, IpProtocol=None, Ipv4Destination=None, Ipv4Source=None, Ipv6Destination=None, Ipv6ExtHeader=None, Ipv6FlowLabel=None, Ipv6NdSll=None, Ipv6NdTarget=None, Ipv6NdTll=None, Ipv6Source=None, MaxByteLength=None, MplsBos=None, MplsLabel=None, MplsTc=None, MplsTtl=None, NetworkTtl=None, OutputPort=None, OutputPortType=None, PbbIsid=None, QueueId=None, SctpDestination=None, SctpSource=None, TcpDestination=None, TcpSource=None, TunnelId=None, UdpDestination=None, UdpSource=None, VlanId=None, VlanPriority=None):
		"""Finds and retrieves switchActionV131LearnedInfo data from the server.

		All named parameters support regex and can be used to selectively retrieve switchActionV131LearnedInfo data from the server.
		By default the find method takes no parameters and will retrieve all switchActionV131LearnedInfo data from the server.

		Args:
			ActionType (str): This describes the action associated with the flow entry.
			ArpDstHwAddress (str): This describes the target hardware address in the ARP payload.
			ArpDstIpv4Address (number): This describes the target IPv4 address in the ARP payload.
			ArpOpcode (number): This describes the ARP opcode.
			ArpSrcHwAddress (str): This describes the source hardware address in the ARP payload.
			ArpSrcIpv4Address (number): This describes the source IPv4 address in the ARP payload.
			EthernetDestination (str): This describes the destination address of the Ethernet port.
			EthernetSource (str): This describes the source address of the Ethernet port.
			EthernetType (str): This describes the Ethernet type of the flow match.
			Experimenter (number): This describes the unique Experimenter identifier. The default value is 1.
			ExperimenterData (str): This describes the data of the Experimenter.
			ExperimenterDatalength (number): This describes the data length of the Experimenter.
			GroupId (number): NOT DEFINED
			Icmpv4Code (number): This describes the ICMP code.
			Icmpv4Type (number): This describes the ICMP type.
			Icmpv6Code (number): This describes the ICMPv6 code.
			Icmpv6Type (number): This describes the ICMPv6 type.
			IpDscp (str): This describes the IP DSCP value for advertising.
			IpEcn (number): This describes the ECN bits of the IP header.
			IpProtocol (number): This describes the IP Protocol used.
			Ipv4Destination (str): This describes the IPv4 destination address.
			Ipv4Source (str): This describes the IPv4 source address.
			Ipv6Destination (str): This describes the IPv6 destination address.
			Ipv6ExtHeader (number): This describes the IPv6 Extension Header pseudo-field.
			Ipv6FlowLabel (number): This describes the IPv6 Flow label.
			Ipv6NdSll (str): This describes the source link-layer address option in an IPv6 Neighbor Discovery message.
			Ipv6NdTarget (str): This describes the target address in an IPv6 Neighbor Discovery message.
			Ipv6NdTll (str): This describes the target link-layer address option in an IPv6 Neighbor Discovery message
			Ipv6Source (str): This describes the IPv6 source address.
			MaxByteLength (number): This describes the maximum amount of data from a packet that should be sent when the port is OFPP_CONTROLLER.
			MplsBos (number): This describes the BoS bit in the first MPLS shim header.
			MplsLabel (number): This describes the LABEL in the first MPLS shim header.
			MplsTc (number): This describes the TC in the first MPLS shim header.
			MplsTtl (number): This replaces the existing MPLS TTL. Only applies to packets with an existing MPLS shim header.
			NetworkTtl (number): This describes the IP TTL.
			OutputPort (number): This describes the out port value. It requires matching entries to include this as an output port.
			OutputPortType (str): This describes the Output Port Type for this Flow Range
			PbbIsid (number): This describes the I-SID in the first PBB service instance tag.
			QueueId (number): This describes the queue of the port in which the packet should be enqueued.
			SctpDestination (number): This describes the SCTP target port.
			SctpSource (number): This describes the SCTP source port.
			TcpDestination (number): This describes the TCP destination address.
			TcpSource (number): This describes the TCP source address.
			TunnelId (str): This describes the unique identifier used for the Tunnel.
			UdpDestination (number): This describes the UDP destination port.
			UdpSource (number): This describes the UDP source port.
			VlanId (number): This describes the unique VLAN Identifier.
			VlanPriority (number): This describes the User Priority for this VLAN.

		Returns:
			self: This instance with matching switchActionV131LearnedInfo data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of switchActionV131LearnedInfo data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the switchActionV131LearnedInfo data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LearnedFilter(Base):
	"""The LearnedFilter class encapsulates a required learnedFilter node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LearnedFilter property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'learnedFilter'

	def __init__(self, parent):
		super(LearnedFilter, self).__init__(parent)

	@property
	def Capabilities(self):
		"""An instance of the Capabilities class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.capabilities.Capabilities)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.capabilities import Capabilities
		return Capabilities(self)._select()

	@property
	def Prefix(self):
		"""An instance of the Prefix class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.prefix.Prefix)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.bgp.prefix import Prefix
		return Prefix(self)._select()

	@property
	def Afi(self):
		"""Address Family Identifier value. Identifies the network layer protocol to be used with these routes.

		Returns:
			number
		"""
		return self._get_attribute('afi')
	@Afi.setter
	def Afi(self, value):
		self._set_attribute('afi', value)

	@property
	def EnableAfiSafi(self):
		"""If enabled, allows the user to set values to be used for BGP-MP - the user-specified AFI and SAFI values for the BGP MP_REACH_NLRI.

		Returns:
			bool
		"""
		return self._get_attribute('enableAfiSafi')
	@EnableAfiSafi.setter
	def EnableAfiSafi(self, value):
		self._set_attribute('enableAfiSafi', value)

	@property
	def EnablePrefix(self):
		"""If enabled, BGP Prefix Filters configured in this dialog will be used to filter for routes that match those filter entries. Only those routes will be stored in the routing table. If disabled, all learned BGP routes will be stored.

		Returns:
			bool
		"""
		return self._get_attribute('enablePrefix')
	@EnablePrefix.setter
	def EnablePrefix(self, value):
		self._set_attribute('enablePrefix', value)

	@property
	def Safi(self):
		"""Subsequent Address Family Identifier value. Used with, and provides additional information about, the AFI in the NLRI, per RFC 2858.

		Returns:
			number
		"""
		return self._get_attribute('safi')
	@Safi.setter
	def Safi(self, value):
		self._set_attribute('safi', value)

	def update(self, Afi=None, EnableAfiSafi=None, EnablePrefix=None, Safi=None):
		"""Updates a child instance of learnedFilter on the server.

		Args:
			Afi (number): Address Family Identifier value. Identifies the network layer protocol to be used with these routes.
			EnableAfiSafi (bool): If enabled, allows the user to set values to be used for BGP-MP - the user-specified AFI and SAFI values for the BGP MP_REACH_NLRI.
			EnablePrefix (bool): If enabled, BGP Prefix Filters configured in this dialog will be used to filter for routes that match those filter entries. Only those routes will be stored in the routing table. If disabled, all learned BGP routes will be stored.
			Safi (number): Subsequent Address Family Identifier value. Used with, and provides additional information about, the AFI in the NLRI, per RFC 2858.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class ControllerTables(Base):
	"""The ControllerTables class encapsulates a user managed controllerTables node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the ControllerTables property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'controllerTables'

	def __init__(self, parent):
		super(ControllerTables, self).__init__(parent)

	@property
	def ApplyActions(self):
		"""An instance of the ApplyActions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applyactions.ApplyActions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applyactions import ApplyActions
		return ApplyActions(self)._select()

	@property
	def ApplyActionsMiss(self):
		"""An instance of the ApplyActionsMiss class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applyactionsmiss.ApplyActionsMiss)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applyactionsmiss import ApplyActionsMiss
		return ApplyActionsMiss(self)._select()

	@property
	def ApplySetField(self):
		"""An instance of the ApplySetField class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applysetfield.ApplySetField)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applysetfield import ApplySetField
		return ApplySetField(self)._select()

	@property
	def ApplySetFieldMiss(self):
		"""An instance of the ApplySetFieldMiss class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applysetfieldmiss.ApplySetFieldMiss)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applysetfieldmiss import ApplySetFieldMiss
		return ApplySetFieldMiss(self)._select()

	@property
	def ControllerTableFlowRanges(self):
		"""An instance of the ControllerTableFlowRanges class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.controllertableflowranges.ControllerTableFlowRanges)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.controllertableflowranges import ControllerTableFlowRanges
		return ControllerTableFlowRanges(self)

	@property
	def FeaturesSupported(self):
		"""An instance of the FeaturesSupported class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.featuressupported.FeaturesSupported)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.featuressupported import FeaturesSupported
		return FeaturesSupported(self)._select()

	@property
	def Instruction(self):
		"""An instance of the Instruction class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instruction.Instruction)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instruction import Instruction
		return Instruction(self)._select()

	@property
	def InstructionMiss(self):
		"""An instance of the InstructionMiss class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instructionmiss.InstructionMiss)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instructionmiss import InstructionMiss
		return InstructionMiss(self)._select()

	@property
	def Match(self):
		"""An instance of the Match class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.match.Match)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.match import Match
		return Match(self)._select()

	@property
	def TableModificationTriggerAttributes(self):
		"""An instance of the TableModificationTriggerAttributes class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.tablemodificationtriggerattributes.TableModificationTriggerAttributes)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.tablemodificationtriggerattributes import TableModificationTriggerAttributes
		return TableModificationTriggerAttributes(self)._select()

	@property
	def Wildcards(self):
		"""An instance of the Wildcards class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.wildcards.Wildcards)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.wildcards import Wildcards
		return Wildcards(self)._select()

	@property
	def WriteActions(self):
		"""An instance of the WriteActions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writeactions.WriteActions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writeactions import WriteActions
		return WriteActions(self)._select()

	@property
	def WriteActionsMiss(self):
		"""An instance of the WriteActionsMiss class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writeactionsmiss.WriteActionsMiss)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writeactionsmiss import WriteActionsMiss
		return WriteActionsMiss(self)._select()

	@property
	def WriteSetField(self):
		"""An instance of the WriteSetField class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writesetfield.WriteSetField)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writesetfield import WriteSetField
		return WriteSetField(self)._select()

	@property
	def WriteSetFieldMiss(self):
		"""An instance of the WriteSetFieldMiss class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writesetfieldmiss.WriteSetFieldMiss)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writesetfieldmiss import WriteSetFieldMiss
		return WriteSetFieldMiss(self)._select()

	@property
	def ApplyActionExperimenterData(self):
		"""The data of the Apply Action Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('applyActionExperimenterData')
	@ApplyActionExperimenterData.setter
	def ApplyActionExperimenterData(self, value):
		self._set_attribute('applyActionExperimenterData', value)

	@property
	def ApplyActionExperimenterDataLength(self):
		"""The data length of the Apply Action Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('applyActionExperimenterDataLength')
	@ApplyActionExperimenterDataLength.setter
	def ApplyActionExperimenterDataLength(self, value):
		self._set_attribute('applyActionExperimenterDataLength', value)

	@property
	def ApplyActionExperimenterId(self):
		"""The unique identifier for Apply Action Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('applyActionExperimenterId')
	@ApplyActionExperimenterId.setter
	def ApplyActionExperimenterId(self, value):
		self._set_attribute('applyActionExperimenterId', value)

	@property
	def ApplyActionMissExperimenterData(self):
		"""Experimenter Data The data of the apply action for table-miss of Controller Table Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('applyActionMissExperimenterData')
	@ApplyActionMissExperimenterData.setter
	def ApplyActionMissExperimenterData(self, value):
		self._set_attribute('applyActionMissExperimenterData', value)

	@property
	def ApplyActionMissExperimenterDataLength(self):
		"""The data length of the Apply Action Miss Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('applyActionMissExperimenterDataLength')
	@ApplyActionMissExperimenterDataLength.setter
	def ApplyActionMissExperimenterDataLength(self, value):
		self._set_attribute('applyActionMissExperimenterDataLength', value)

	@property
	def ApplyActionMissExperimenterId(self):
		"""The unique identifier for Apply Action Miss Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('applyActionMissExperimenterId')
	@ApplyActionMissExperimenterId.setter
	def ApplyActionMissExperimenterId(self, value):
		self._set_attribute('applyActionMissExperimenterId', value)

	@property
	def Config(self):
		"""Specify the bitmap of OFPTC_* values. The default value is 0.

		Returns:
			number
		"""
		return self._get_attribute('config')
	@Config.setter
	def Config(self, value):
		self._set_attribute('config', value)

	@property
	def Enabled(self):
		"""If selected, this table is used in this controller configuration.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def ExperimenterData(self):
		"""The data of the Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('experimenterData')
	@ExperimenterData.setter
	def ExperimenterData(self, value):
		self._set_attribute('experimenterData', value)

	@property
	def ExperimenterDataLength(self):
		"""The data length of the Experimenter for table-miss.

		Returns:
			number
		"""
		return self._get_attribute('experimenterDataLength')
	@ExperimenterDataLength.setter
	def ExperimenterDataLength(self, value):
		self._set_attribute('experimenterDataLength', value)

	@property
	def ExperimenterId(self):
		"""The unique identifier for the Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('experimenterId')
	@ExperimenterId.setter
	def ExperimenterId(self, value):
		self._set_attribute('experimenterId', value)

	@property
	def ExperimenterMissData(self):
		"""The data of the Experimenter for table-miss.

		Returns:
			str
		"""
		return self._get_attribute('experimenterMissData')
	@ExperimenterMissData.setter
	def ExperimenterMissData(self, value):
		self._set_attribute('experimenterMissData', value)

	@property
	def ExperimenterMissDataLength(self):
		"""The data length of the Experimenter for table-miss.

		Returns:
			number
		"""
		return self._get_attribute('experimenterMissDataLength')
	@ExperimenterMissDataLength.setter
	def ExperimenterMissDataLength(self, value):
		self._set_attribute('experimenterMissDataLength', value)

	@property
	def ExperimenterMissId(self):
		"""The unique identifier for the Experimenter for table-miss.

		Returns:
			number
		"""
		return self._get_attribute('experimenterMissId')
	@ExperimenterMissId.setter
	def ExperimenterMissId(self, value):
		self._set_attribute('experimenterMissId', value)

	@property
	def ExperimenterMissType(self):
		"""The type of experimenter for table-miss.

		Returns:
			number
		"""
		return self._get_attribute('experimenterMissType')
	@ExperimenterMissType.setter
	def ExperimenterMissType(self, value):
		self._set_attribute('experimenterMissType', value)

	@property
	def ExperimenterType(self):
		"""The type of experimenter.

		Returns:
			number
		"""
		return self._get_attribute('experimenterType')
	@ExperimenterType.setter
	def ExperimenterType(self, value):
		self._set_attribute('experimenterType', value)

	@property
	def InstructionExperimenterData(self):
		"""The data of the Instruction Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('instructionExperimenterData')
	@InstructionExperimenterData.setter
	def InstructionExperimenterData(self, value):
		self._set_attribute('instructionExperimenterData', value)

	@property
	def InstructionExperimenterDataLength(self):
		"""The data length of the experimental instruction of Controller Table Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('instructionExperimenterDataLength')
	@InstructionExperimenterDataLength.setter
	def InstructionExperimenterDataLength(self, value):
		self._set_attribute('instructionExperimenterDataLength', value)

	@property
	def InstructionExperimenterId(self):
		"""The unique identifier for the Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('instructionExperimenterId')
	@InstructionExperimenterId.setter
	def InstructionExperimenterId(self, value):
		self._set_attribute('instructionExperimenterId', value)

	@property
	def InstructionMissExperimenterData(self):
		"""The data of the Instruction Miss Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('instructionMissExperimenterData')
	@InstructionMissExperimenterData.setter
	def InstructionMissExperimenterData(self, value):
		self._set_attribute('instructionMissExperimenterData', value)

	@property
	def InstructionMissExperimenterDataLength(self):
		"""It indicates the data length of the Instruction Miss Experimenter

		Returns:
			number
		"""
		return self._get_attribute('instructionMissExperimenterDataLength')
	@InstructionMissExperimenterDataLength.setter
	def InstructionMissExperimenterDataLength(self, value):
		self._set_attribute('instructionMissExperimenterDataLength', value)

	@property
	def InstructionMissExperimenterId(self):
		"""The unique identifier of Instruction Miss Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('instructionMissExperimenterId')
	@InstructionMissExperimenterId.setter
	def InstructionMissExperimenterId(self, value):
		self._set_attribute('instructionMissExperimenterId', value)

	@property
	def MatchExperimenterData(self):
		"""The match data of the Controller Table Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('matchExperimenterData')
	@MatchExperimenterData.setter
	def MatchExperimenterData(self, value):
		self._set_attribute('matchExperimenterData', value)

	@property
	def MatchExperimenterDataLength(self):
		"""The data length of the wildcard experimenter of Controller Table Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('matchExperimenterDataLength')
	@MatchExperimenterDataLength.setter
	def MatchExperimenterDataLength(self, value):
		self._set_attribute('matchExperimenterDataLength', value)

	@property
	def MatchExperimenterField(self):
		"""The identifier for match experimenter of Controller Table Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('matchExperimenterField')
	@MatchExperimenterField.setter
	def MatchExperimenterField(self, value):
		self._set_attribute('matchExperimenterField', value)

	@property
	def MatchExperimenterHasMask(self):
		"""Mask If selected, the match experimenter hash mask field of Controller Table Experimenter is available.

		Returns:
			bool
		"""
		return self._get_attribute('matchExperimenterHasMask')
	@MatchExperimenterHasMask.setter
	def MatchExperimenterHasMask(self, value):
		self._set_attribute('matchExperimenterHasMask', value)

	@property
	def MatchExperimenterId(self):
		"""The unique identifier for wildcard experimenter of Controller Table Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('matchExperimenterId')
	@MatchExperimenterId.setter
	def MatchExperimenterId(self, value):
		self._set_attribute('matchExperimenterId', value)

	@property
	def MaxEntries(self):
		"""Specify the maximum number of entries supported. The default value is 0.

		Returns:
			number
		"""
		return self._get_attribute('maxEntries')
	@MaxEntries.setter
	def MaxEntries(self, value):
		self._set_attribute('maxEntries', value)

	@property
	def MetadataMatch(self):
		"""Specify the bits of metadata table that can match. The default value is 0.

		Returns:
			str
		"""
		return self._get_attribute('metadataMatch')
	@MetadataMatch.setter
	def MetadataMatch(self, value):
		self._set_attribute('metadataMatch', value)

	@property
	def MetadataWrite(self):
		"""Specify the bits of metadata table that can write. The default value is 0.

		Returns:
			str
		"""
		return self._get_attribute('metadataWrite')
	@MetadataWrite.setter
	def MetadataWrite(self, value):
		self._set_attribute('metadataWrite', value)

	@property
	def NextTable(self):
		"""Next table property.

		Returns:
			str
		"""
		return self._get_attribute('nextTable')
	@NextTable.setter
	def NextTable(self, value):
		self._set_attribute('nextTable', value)

	@property
	def NextTableMiss(self):
		"""Next table for table-miss.

		Returns:
			str
		"""
		return self._get_attribute('nextTableMiss')
	@NextTableMiss.setter
	def NextTableMiss(self, value):
		self._set_attribute('nextTableMiss', value)

	@property
	def TableId(self):
		"""Specify the controller table identifier. Lower numbered tables are consulted first.

		Returns:
			number
		"""
		return self._get_attribute('tableId')
	@TableId.setter
	def TableId(self, value):
		self._set_attribute('tableId', value)

	@property
	def TableName(self):
		"""Specify the name of the controller table.

		Returns:
			str
		"""
		return self._get_attribute('tableName')
	@TableName.setter
	def TableName(self, value):
		self._set_attribute('tableName', value)

	@property
	def WildcardExperimenterData(self):
		"""The data of the wildcard experimenter of Controller Table Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('wildcardExperimenterData')
	@WildcardExperimenterData.setter
	def WildcardExperimenterData(self, value):
		self._set_attribute('wildcardExperimenterData', value)

	@property
	def WildcardExperimenterDataLength(self):
		"""The data length of the wildcard experimenter of Controller Table Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('wildcardExperimenterDataLength')
	@WildcardExperimenterDataLength.setter
	def WildcardExperimenterDataLength(self, value):
		self._set_attribute('wildcardExperimenterDataLength', value)

	@property
	def WildcardExperimenterField(self):
		"""The identifier for wildcard experimenter of Controller Table Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('wildcardExperimenterField')
	@WildcardExperimenterField.setter
	def WildcardExperimenterField(self, value):
		self._set_attribute('wildcardExperimenterField', value)

	@property
	def WildcardExperimenterHasMask(self):
		"""Mask If selected, the wildcard experimenter hash mask field of Controller Table Experimenter is available.

		Returns:
			bool
		"""
		return self._get_attribute('wildcardExperimenterHasMask')
	@WildcardExperimenterHasMask.setter
	def WildcardExperimenterHasMask(self, value):
		self._set_attribute('wildcardExperimenterHasMask', value)

	@property
	def WildcardExperimenterId(self):
		"""The unique identifier for wildcard experimenter of Controller Table Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('wildcardExperimenterId')
	@WildcardExperimenterId.setter
	def WildcardExperimenterId(self, value):
		self._set_attribute('wildcardExperimenterId', value)

	@property
	def WriteActionExperimenterData(self):
		"""The data of the Write Action Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('writeActionExperimenterData')
	@WriteActionExperimenterData.setter
	def WriteActionExperimenterData(self, value):
		self._set_attribute('writeActionExperimenterData', value)

	@property
	def WriteActionExperimenterDataLength(self):
		"""The data length of the Write Action Miss Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('writeActionExperimenterDataLength')
	@WriteActionExperimenterDataLength.setter
	def WriteActionExperimenterDataLength(self, value):
		self._set_attribute('writeActionExperimenterDataLength', value)

	@property
	def WriteActionExperimenterId(self):
		"""The unique identifier for Write Action Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('writeActionExperimenterId')
	@WriteActionExperimenterId.setter
	def WriteActionExperimenterId(self, value):
		self._set_attribute('writeActionExperimenterId', value)

	@property
	def WriteActionMissExperimenterData(self):
		"""The data of the Write Action Miss Experimenter.

		Returns:
			str
		"""
		return self._get_attribute('writeActionMissExperimenterData')
	@WriteActionMissExperimenterData.setter
	def WriteActionMissExperimenterData(self, value):
		self._set_attribute('writeActionMissExperimenterData', value)

	@property
	def WriteActionMissExperimenterDataLength(self):
		"""The data length of the Write Action Miss Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('writeActionMissExperimenterDataLength')
	@WriteActionMissExperimenterDataLength.setter
	def WriteActionMissExperimenterDataLength(self, value):
		self._set_attribute('writeActionMissExperimenterDataLength', value)

	@property
	def WriteActionMissExperimenterId(self):
		"""The unique identifier of Write Action Miss Experimenter.

		Returns:
			number
		"""
		return self._get_attribute('writeActionMissExperimenterId')
	@WriteActionMissExperimenterId.setter
	def WriteActionMissExperimenterId(self, value):
		self._set_attribute('writeActionMissExperimenterId', value)

	def update(self, ApplyActionExperimenterData=None, ApplyActionExperimenterDataLength=None, ApplyActionExperimenterId=None, ApplyActionMissExperimenterData=None, ApplyActionMissExperimenterDataLength=None, ApplyActionMissExperimenterId=None, Config=None, Enabled=None, ExperimenterData=None, ExperimenterDataLength=None, ExperimenterId=None, ExperimenterMissData=None, ExperimenterMissDataLength=None, ExperimenterMissId=None, ExperimenterMissType=None, ExperimenterType=None, InstructionExperimenterData=None, InstructionExperimenterDataLength=None, InstructionExperimenterId=None, InstructionMissExperimenterData=None, InstructionMissExperimenterDataLength=None, InstructionMissExperimenterId=None, MatchExperimenterData=None, MatchExperimenterDataLength=None, MatchExperimenterField=None, MatchExperimenterHasMask=None, MatchExperimenterId=None, MaxEntries=None, MetadataMatch=None, MetadataWrite=None, NextTable=None, NextTableMiss=None, TableId=None, TableName=None, WildcardExperimenterData=None, WildcardExperimenterDataLength=None, WildcardExperimenterField=None, WildcardExperimenterHasMask=None, WildcardExperimenterId=None, WriteActionExperimenterData=None, WriteActionExperimenterDataLength=None, WriteActionExperimenterId=None, WriteActionMissExperimenterData=None, WriteActionMissExperimenterDataLength=None, WriteActionMissExperimenterId=None):
		"""Updates a child instance of controllerTables on the server.

		Args:
			ApplyActionExperimenterData (str): The data of the Apply Action Experimenter.
			ApplyActionExperimenterDataLength (number): The data length of the Apply Action Experimenter.
			ApplyActionExperimenterId (number): The unique identifier for Apply Action Experimenter.
			ApplyActionMissExperimenterData (str): Experimenter Data The data of the apply action for table-miss of Controller Table Experimenter.
			ApplyActionMissExperimenterDataLength (number): The data length of the Apply Action Miss Experimenter.
			ApplyActionMissExperimenterId (number): The unique identifier for Apply Action Miss Experimenter.
			Config (number): Specify the bitmap of OFPTC_* values. The default value is 0.
			Enabled (bool): If selected, this table is used in this controller configuration.
			ExperimenterData (str): The data of the Experimenter.
			ExperimenterDataLength (number): The data length of the Experimenter for table-miss.
			ExperimenterId (number): The unique identifier for the Experimenter.
			ExperimenterMissData (str): The data of the Experimenter for table-miss.
			ExperimenterMissDataLength (number): The data length of the Experimenter for table-miss.
			ExperimenterMissId (number): The unique identifier for the Experimenter for table-miss.
			ExperimenterMissType (number): The type of experimenter for table-miss.
			ExperimenterType (number): The type of experimenter.
			InstructionExperimenterData (str): The data of the Instruction Experimenter.
			InstructionExperimenterDataLength (number): The data length of the experimental instruction of Controller Table Experimenter.
			InstructionExperimenterId (number): The unique identifier for the Experimenter.
			InstructionMissExperimenterData (str): The data of the Instruction Miss Experimenter.
			InstructionMissExperimenterDataLength (number): It indicates the data length of the Instruction Miss Experimenter
			InstructionMissExperimenterId (number): The unique identifier of Instruction Miss Experimenter.
			MatchExperimenterData (str): The match data of the Controller Table Experimenter.
			MatchExperimenterDataLength (number): The data length of the wildcard experimenter of Controller Table Experimenter.
			MatchExperimenterField (number): The identifier for match experimenter of Controller Table Experimenter.
			MatchExperimenterHasMask (bool): Mask If selected, the match experimenter hash mask field of Controller Table Experimenter is available.
			MatchExperimenterId (number): The unique identifier for wildcard experimenter of Controller Table Experimenter.
			MaxEntries (number): Specify the maximum number of entries supported. The default value is 0.
			MetadataMatch (str): Specify the bits of metadata table that can match. The default value is 0.
			MetadataWrite (str): Specify the bits of metadata table that can write. The default value is 0.
			NextTable (str): Next table property.
			NextTableMiss (str): Next table for table-miss.
			TableId (number): Specify the controller table identifier. Lower numbered tables are consulted first.
			TableName (str): Specify the name of the controller table.
			WildcardExperimenterData (str): The data of the wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterDataLength (number): The data length of the wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterField (number): The identifier for wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterHasMask (bool): Mask If selected, the wildcard experimenter hash mask field of Controller Table Experimenter is available.
			WildcardExperimenterId (number): The unique identifier for wildcard experimenter of Controller Table Experimenter.
			WriteActionExperimenterData (str): The data of the Write Action Experimenter.
			WriteActionExperimenterDataLength (number): The data length of the Write Action Miss Experimenter.
			WriteActionExperimenterId (number): The unique identifier for Write Action Experimenter.
			WriteActionMissExperimenterData (str): The data of the Write Action Miss Experimenter.
			WriteActionMissExperimenterDataLength (number): The data length of the Write Action Miss Experimenter.
			WriteActionMissExperimenterId (number): The unique identifier of Write Action Miss Experimenter.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ApplyActionExperimenterData=None, ApplyActionExperimenterDataLength=None, ApplyActionExperimenterId=None, ApplyActionMissExperimenterData=None, ApplyActionMissExperimenterDataLength=None, ApplyActionMissExperimenterId=None, Config=None, Enabled=None, ExperimenterData=None, ExperimenterDataLength=None, ExperimenterId=None, ExperimenterMissData=None, ExperimenterMissDataLength=None, ExperimenterMissId=None, ExperimenterMissType=None, ExperimenterType=None, InstructionExperimenterData=None, InstructionExperimenterDataLength=None, InstructionExperimenterId=None, InstructionMissExperimenterData=None, InstructionMissExperimenterDataLength=None, InstructionMissExperimenterId=None, MatchExperimenterData=None, MatchExperimenterDataLength=None, MatchExperimenterField=None, MatchExperimenterHasMask=None, MatchExperimenterId=None, MaxEntries=None, MetadataMatch=None, MetadataWrite=None, NextTable=None, NextTableMiss=None, TableId=None, TableName=None, WildcardExperimenterData=None, WildcardExperimenterDataLength=None, WildcardExperimenterField=None, WildcardExperimenterHasMask=None, WildcardExperimenterId=None, WriteActionExperimenterData=None, WriteActionExperimenterDataLength=None, WriteActionExperimenterId=None, WriteActionMissExperimenterData=None, WriteActionMissExperimenterDataLength=None, WriteActionMissExperimenterId=None):
		"""Adds a new controllerTables node on the server and retrieves it in this instance.

		Args:
			ApplyActionExperimenterData (str): The data of the Apply Action Experimenter.
			ApplyActionExperimenterDataLength (number): The data length of the Apply Action Experimenter.
			ApplyActionExperimenterId (number): The unique identifier for Apply Action Experimenter.
			ApplyActionMissExperimenterData (str): Experimenter Data The data of the apply action for table-miss of Controller Table Experimenter.
			ApplyActionMissExperimenterDataLength (number): The data length of the Apply Action Miss Experimenter.
			ApplyActionMissExperimenterId (number): The unique identifier for Apply Action Miss Experimenter.
			Config (number): Specify the bitmap of OFPTC_* values. The default value is 0.
			Enabled (bool): If selected, this table is used in this controller configuration.
			ExperimenterData (str): The data of the Experimenter.
			ExperimenterDataLength (number): The data length of the Experimenter for table-miss.
			ExperimenterId (number): The unique identifier for the Experimenter.
			ExperimenterMissData (str): The data of the Experimenter for table-miss.
			ExperimenterMissDataLength (number): The data length of the Experimenter for table-miss.
			ExperimenterMissId (number): The unique identifier for the Experimenter for table-miss.
			ExperimenterMissType (number): The type of experimenter for table-miss.
			ExperimenterType (number): The type of experimenter.
			InstructionExperimenterData (str): The data of the Instruction Experimenter.
			InstructionExperimenterDataLength (number): The data length of the experimental instruction of Controller Table Experimenter.
			InstructionExperimenterId (number): The unique identifier for the Experimenter.
			InstructionMissExperimenterData (str): The data of the Instruction Miss Experimenter.
			InstructionMissExperimenterDataLength (number): It indicates the data length of the Instruction Miss Experimenter
			InstructionMissExperimenterId (number): The unique identifier of Instruction Miss Experimenter.
			MatchExperimenterData (str): The match data of the Controller Table Experimenter.
			MatchExperimenterDataLength (number): The data length of the wildcard experimenter of Controller Table Experimenter.
			MatchExperimenterField (number): The identifier for match experimenter of Controller Table Experimenter.
			MatchExperimenterHasMask (bool): Mask If selected, the match experimenter hash mask field of Controller Table Experimenter is available.
			MatchExperimenterId (number): The unique identifier for wildcard experimenter of Controller Table Experimenter.
			MaxEntries (number): Specify the maximum number of entries supported. The default value is 0.
			MetadataMatch (str): Specify the bits of metadata table that can match. The default value is 0.
			MetadataWrite (str): Specify the bits of metadata table that can write. The default value is 0.
			NextTable (str): Next table property.
			NextTableMiss (str): Next table for table-miss.
			TableId (number): Specify the controller table identifier. Lower numbered tables are consulted first.
			TableName (str): Specify the name of the controller table.
			WildcardExperimenterData (str): The data of the wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterDataLength (number): The data length of the wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterField (number): The identifier for wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterHasMask (bool): Mask If selected, the wildcard experimenter hash mask field of Controller Table Experimenter is available.
			WildcardExperimenterId (number): The unique identifier for wildcard experimenter of Controller Table Experimenter.
			WriteActionExperimenterData (str): The data of the Write Action Experimenter.
			WriteActionExperimenterDataLength (number): The data length of the Write Action Miss Experimenter.
			WriteActionExperimenterId (number): The unique identifier for Write Action Experimenter.
			WriteActionMissExperimenterData (str): The data of the Write Action Miss Experimenter.
			WriteActionMissExperimenterDataLength (number): The data length of the Write Action Miss Experimenter.
			WriteActionMissExperimenterId (number): The unique identifier of Write Action Miss Experimenter.

		Returns:
			self: This instance with all currently retrieved controllerTables data using find and the newly added controllerTables data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the controllerTables data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ApplyActionExperimenterData=None, ApplyActionExperimenterDataLength=None, ApplyActionExperimenterId=None, ApplyActionMissExperimenterData=None, ApplyActionMissExperimenterDataLength=None, ApplyActionMissExperimenterId=None, Config=None, Enabled=None, ExperimenterData=None, ExperimenterDataLength=None, ExperimenterId=None, ExperimenterMissData=None, ExperimenterMissDataLength=None, ExperimenterMissId=None, ExperimenterMissType=None, ExperimenterType=None, InstructionExperimenterData=None, InstructionExperimenterDataLength=None, InstructionExperimenterId=None, InstructionMissExperimenterData=None, InstructionMissExperimenterDataLength=None, InstructionMissExperimenterId=None, MatchExperimenterData=None, MatchExperimenterDataLength=None, MatchExperimenterField=None, MatchExperimenterHasMask=None, MatchExperimenterId=None, MaxEntries=None, MetadataMatch=None, MetadataWrite=None, NextTable=None, NextTableMiss=None, TableId=None, TableName=None, WildcardExperimenterData=None, WildcardExperimenterDataLength=None, WildcardExperimenterField=None, WildcardExperimenterHasMask=None, WildcardExperimenterId=None, WriteActionExperimenterData=None, WriteActionExperimenterDataLength=None, WriteActionExperimenterId=None, WriteActionMissExperimenterData=None, WriteActionMissExperimenterDataLength=None, WriteActionMissExperimenterId=None):
		"""Finds and retrieves controllerTables data from the server.

		All named parameters support regex and can be used to selectively retrieve controllerTables data from the server.
		By default the find method takes no parameters and will retrieve all controllerTables data from the server.

		Args:
			ApplyActionExperimenterData (str): The data of the Apply Action Experimenter.
			ApplyActionExperimenterDataLength (number): The data length of the Apply Action Experimenter.
			ApplyActionExperimenterId (number): The unique identifier for Apply Action Experimenter.
			ApplyActionMissExperimenterData (str): Experimenter Data The data of the apply action for table-miss of Controller Table Experimenter.
			ApplyActionMissExperimenterDataLength (number): The data length of the Apply Action Miss Experimenter.
			ApplyActionMissExperimenterId (number): The unique identifier for Apply Action Miss Experimenter.
			Config (number): Specify the bitmap of OFPTC_* values. The default value is 0.
			Enabled (bool): If selected, this table is used in this controller configuration.
			ExperimenterData (str): The data of the Experimenter.
			ExperimenterDataLength (number): The data length of the Experimenter for table-miss.
			ExperimenterId (number): The unique identifier for the Experimenter.
			ExperimenterMissData (str): The data of the Experimenter for table-miss.
			ExperimenterMissDataLength (number): The data length of the Experimenter for table-miss.
			ExperimenterMissId (number): The unique identifier for the Experimenter for table-miss.
			ExperimenterMissType (number): The type of experimenter for table-miss.
			ExperimenterType (number): The type of experimenter.
			InstructionExperimenterData (str): The data of the Instruction Experimenter.
			InstructionExperimenterDataLength (number): The data length of the experimental instruction of Controller Table Experimenter.
			InstructionExperimenterId (number): The unique identifier for the Experimenter.
			InstructionMissExperimenterData (str): The data of the Instruction Miss Experimenter.
			InstructionMissExperimenterDataLength (number): It indicates the data length of the Instruction Miss Experimenter
			InstructionMissExperimenterId (number): The unique identifier of Instruction Miss Experimenter.
			MatchExperimenterData (str): The match data of the Controller Table Experimenter.
			MatchExperimenterDataLength (number): The data length of the wildcard experimenter of Controller Table Experimenter.
			MatchExperimenterField (number): The identifier for match experimenter of Controller Table Experimenter.
			MatchExperimenterHasMask (bool): Mask If selected, the match experimenter hash mask field of Controller Table Experimenter is available.
			MatchExperimenterId (number): The unique identifier for wildcard experimenter of Controller Table Experimenter.
			MaxEntries (number): Specify the maximum number of entries supported. The default value is 0.
			MetadataMatch (str): Specify the bits of metadata table that can match. The default value is 0.
			MetadataWrite (str): Specify the bits of metadata table that can write. The default value is 0.
			NextTable (str): Next table property.
			NextTableMiss (str): Next table for table-miss.
			TableId (number): Specify the controller table identifier. Lower numbered tables are consulted first.
			TableName (str): Specify the name of the controller table.
			WildcardExperimenterData (str): The data of the wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterDataLength (number): The data length of the wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterField (number): The identifier for wildcard experimenter of Controller Table Experimenter.
			WildcardExperimenterHasMask (bool): Mask If selected, the wildcard experimenter hash mask field of Controller Table Experimenter is available.
			WildcardExperimenterId (number): The unique identifier for wildcard experimenter of Controller Table Experimenter.
			WriteActionExperimenterData (str): The data of the Write Action Experimenter.
			WriteActionExperimenterDataLength (number): The data length of the Write Action Miss Experimenter.
			WriteActionExperimenterId (number): The unique identifier for Write Action Experimenter.
			WriteActionMissExperimenterData (str): The data of the Write Action Miss Experimenter.
			WriteActionMissExperimenterDataLength (number): The data length of the Write Action Miss Experimenter.
			WriteActionMissExperimenterId (number): The unique identifier of Write Action Miss Experimenter.

		Returns:
			self: This instance with matching controllerTables data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of controllerTables data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the controllerTables data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def TableModificationTrigger(self):
		"""Executes the tableModificationTrigger operation on the server.

		NOT DEFINED

			Returns:
				bool: NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('tableModificationTrigger', payload=payload, response_object=None)



"""Demonstrates ixnetwork_restpy container object functionality.

The sample below shows how to retrieve all instances of a node from the server into a single container object
Each instance can be accessed using the container object's iterator or index functionality
The container implements the following special method names to allow for iteration and indexing:
    __len__, __getitem__, __iter__, __next__

The benefit of a container object is that a single method call can act on many instances without having to pass arrays of references.
For example if a container encapsulates 10 instances, the <container>.remove() method will delete all the encapsulated 
instances without having to add looping code

For more information on containers read the following:  
  https://docs.python.org/2.7/reference/datamodel.html#emulating-container-types
  https://docs.python.org/2.7/library/stdtypes.html#typeiter

"""

from ixnetwork_restpy.testplatform.testplatform import TestPlatform


# connect to a test platform
test_platform = TestPlatform('127.0.0.1')

# use the default session and get the root node of the hierarchy
ixnetwork = test_platform.Sessions.find().Ixnetwork

# clear the configuration
ixnetwork.NewConfig()

# create x number of vports
vport_count = 3
for i in range(vport_count):
    ixnetwork.Vport.add()

# get a container object with all instances
vports = ixnetwork.Vport.find()
assert(len(vports) == 3)

# print the number of insances encapsulated in the container
print('%s instances' % len(vports))

# print all instances in the container
print(vports)

# print the first instance
print(vports[0].href)

# print the last instance
print(vports[-1].href)

# convert the container object into a list
vport_list = list(vports)
print(len(vport_list))

# remove all encapsulated instances in a single method call
vports.remove()





# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class MldQuerier(Base):
	"""The MldQuerier class encapsulates a user managed mldQuerier node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the MldQuerier property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'mldQuerier'

	def __init__(self, parent):
		super(MldQuerier, self).__init__(parent)

	@property
	def LearnedInfo(self):
		"""An instance of the LearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo.LearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo import LearnedInfo
		return LearnedInfo(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DiscardLearntInfo(self):
		"""DEPRECATED Discard Learned Info

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('discardLearntInfo')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def GeneralQueryInterval(self):
		"""DEPRECATED General Query Interval in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('generalQueryInterval')

	@property
	def GeneralQueryResponseInterval(self):
		"""DEPRECATED General Query Response Interval in milliseconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('generalQueryResponseInterval')

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def ProxyQuerier(self):
		"""DEPRECATED Enable Proxy Querier

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('proxyQuerier')

	@property
	def RobustnessVariable(self):
		"""DEPRECATED Robustness Variable

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('robustnessVariable')

	@property
	def RouterAlert(self):
		"""DEPRECATED Router Alert

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('routerAlert')

	@property
	def SessionInfo(self):
		"""DEPRECATED Logs additional information about the session state

		Returns:
			list(str[noIfaceUp|up])
		"""
		return self._get_attribute('sessionInfo')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def SpecificQueryResponseInterval(self):
		"""DEPRECATED Specific Query Response Interval in milliseconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('specificQueryResponseInterval')

	@property
	def SpecificQueryTransmissionCount(self):
		"""DEPRECATED Specific Query Transmission Count

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('specificQueryTransmissionCount')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StartupQueryCount(self):
		"""DEPRECATED Startup Query Count

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('startupQueryCount')

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def SupportElection(self):
		"""DEPRECATED Support Election

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportElection')

	@property
	def SupportOlderVersionHost(self):
		"""DEPRECATED Support Older Version Host

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportOlderVersionHost')

	@property
	def SupportOlderVersionQuerier(self):
		"""DEPRECATED Support Older Version Querier

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('supportOlderVersionQuerier')

	@property
	def VersionType(self):
		"""DEPRECATED Version

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('versionType')

	def update(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Updates a child instance of mldQuerier on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Adds a new mldQuerier node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved mldQuerier data using find and the newly added mldQuerier data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the mldQuerier data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, Errors=None, Multiplier=None, Name=None, SessionInfo=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves mldQuerier data from the server.

		All named parameters support regex and can be used to selectively retrieve mldQuerier data from the server.
		By default the find method takes no parameters and will retrieve all mldQuerier data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			SessionInfo (list(str[noIfaceUp|up])): Logs additional information about the session state
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching mldQuerier data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of mldQuerier data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the mldQuerier data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, DiscardLearntInfo=None, GeneralQueryInterval=None, GeneralQueryResponseInterval=None, ProxyQuerier=None, RobustnessVariable=None, RouterAlert=None, SpecificQueryResponseInterval=None, SpecificQueryTransmissionCount=None, StartupQueryCount=None, SupportElection=None, SupportOlderVersionHost=None, SupportOlderVersionQuerier=None, VersionType=None):
		"""Base class infrastructure that gets a list of mldQuerier device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			DiscardLearntInfo (str): optional regex of discardLearntInfo
			GeneralQueryInterval (str): optional regex of generalQueryInterval
			GeneralQueryResponseInterval (str): optional regex of generalQueryResponseInterval
			ProxyQuerier (str): optional regex of proxyQuerier
			RobustnessVariable (str): optional regex of robustnessVariable
			RouterAlert (str): optional regex of routerAlert
			SpecificQueryResponseInterval (str): optional regex of specificQueryResponseInterval
			SpecificQueryTransmissionCount (str): optional regex of specificQueryTransmissionCount
			StartupQueryCount (str): optional regex of startupQueryCount
			SupportElection (str): optional regex of supportElection
			SupportOlderVersionHost (str): optional regex of supportOlderVersionHost
			SupportOlderVersionQuerier (str): optional regex of supportOlderVersionQuerier
			VersionType (str): optional regex of versionType

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def ClearAllLearnedInfoInClient(self, *args, **kwargs):
		"""Executes the clearAllLearnedInfoInClient operation on the server.

		Clears ALL routes from GUI grid for the selected BGP Peers.

		clearAllLearnedInfoInClient(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearAllLearnedInfoInClient', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def GetLearnedInfo(self, *args, **kwargs):
		"""Executes the getLearnedInfo operation on the server.

		Gets all the LSPs and Topologies learnt by this MLD Querier.

		getLearnedInfo(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getLearnedInfo', payload=payload, response_object=None)

	def MldGetLearnedInfo(self, *args, **kwargs):
		"""Executes the mldGetLearnedInfo operation on the server.

		Get Learned Info

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldGetLearnedInfo()

		mldGetLearnedInfo(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldGetLearnedInfo(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldGetLearnedInfo', payload=payload, response_object=None)

	def MldResumePeriodicGenQuery(self, *args, **kwargs):
		"""Executes the mldResumePeriodicGenQuery operation on the server.

		Resume Periodic General Query

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldResumePeriodicGenQuery()

		mldResumePeriodicGenQuery(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldResumePeriodicGenQuery(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldResumePeriodicGenQuery', payload=payload, response_object=None)

	def MldSendSpecificQuery(self, *args, **kwargs):
		"""Executes the mldSendSpecificQuery operation on the server.

		Send Specific Query

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldSendSpecificQuery(Start_group_address:string, Group_count:number, Start_source_address:string, Source_count:number, Source_increment_step:number)
			Args:
				args[0] is Start_group_address (str): This parameter requires a start_group_address of type kString
				args[1] is Group_count (number): This parameter requires a group_count of type kInteger
				args[2] is Start_source_address (str): This parameter requires a start_source_address of type kString
				args[3] is Source_count (number): This parameter requires a source_count of type kInteger
				args[4] is Source_increment_step (number): This parameter requires a source_increment_step of type kInteger

		mldSendSpecificQuery(Start_group_address:string, Group_count:number, Start_source_address:string, Source_count:number, Source_increment_step:number, SessionIndices:list)
			Args:
				args[0] is Start_group_address (str): This parameter requires a start_group_address of type kString
				args[1] is Group_count (number): This parameter requires a group_count of type kInteger
				args[2] is Start_source_address (str): This parameter requires a start_source_address of type kString
				args[3] is Source_count (number): This parameter requires a source_count of type kInteger
				args[4] is Source_increment_step (number): This parameter requires a source_increment_step of type kInteger
				args[5] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldSendSpecificQuery(SessionIndices:string, Start_group_address:string, Group_count:number, Start_source_address:string, Source_count:number, Source_increment_step:number)
			Args:
				args[0] is SessionIndices (str): This parameter requires a start_group_address of type kString
				args[1] is Start_group_address (str): This parameter requires a group_count of type kInteger
				args[2] is Group_count (number): This parameter requires a start_source_address of type kString
				args[3] is Start_source_address (str): This parameter requires a source_count of type kInteger
				args[4] is Source_count (number): This parameter requires a source_increment_step of type kInteger
				args[5] is Source_increment_step (number): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldSendSpecificQuery', payload=payload, response_object=None)

	def MldStartQuerier(self, *args, **kwargs):
		"""Executes the mldStartQuerier operation on the server.

		Start MLD Querier

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldStartQuerier()

		mldStartQuerier(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldStartQuerier(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldStartQuerier', payload=payload, response_object=None)

	def MldStopPeriodicGenQuery(self, *args, **kwargs):
		"""Executes the mldStopPeriodicGenQuery operation on the server.

		Stop Periodic General Query

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldStopPeriodicGenQuery()

		mldStopPeriodicGenQuery(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldStopPeriodicGenQuery(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldStopPeriodicGenQuery', payload=payload, response_object=None)

	def MldStopQuerier(self, *args, **kwargs):
		"""Executes the mldStopQuerier operation on the server.

		Stop MLD Querier

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		mldStopQuerier()

		mldStopQuerier(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		mldStopQuerier(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('mldStopQuerier', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def ResumePeriodicGenQuery(self, *args, **kwargs):
		"""Executes the resumePeriodicGenQuery operation on the server.

		Resume Sending Periodic General Query

		resumePeriodicGenQuery(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('resumePeriodicGenQuery', payload=payload, response_object=None)

	def SendSpecificQuery(self, *args, **kwargs):
		"""Executes the sendSpecificQuery operation on the server.

		Send Specific Query

		sendSpecificQuery(Arg2:list, Arg3:string, Arg4:number, Arg5:string, Arg6:number, Arg7:number)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.
				args[1] is Arg3 (str): Start Group Address.
				args[2] is Arg4 (number): Group Count.
				args[3] is Arg5 (str): Start Source Address.
				args[4] is Arg6 (number): Source Count.
				args[5] is Arg7 (number): Source Increment Step.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendSpecificQuery', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def StartMLD(self, *args, **kwargs):
		"""Executes the startMLD operation on the server.

		Start MLD protocol on selected interfaces

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		startMLD()

		startMLD(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		startMLD(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		startMLD(Arg2:string, Arg3:list)
			Args:
				args[0] is Arg2 (str): ID to associate each async action invocation
				args[1] is Arg3 (list(number)): List of indices into the group range grid An empty list indicates all instances in the plugin.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('startMLD', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)

	def StopMLD(self, *args, **kwargs):
		"""Executes the stopMLD operation on the server.

		Stop MLD protocol on selected interfaces

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stopMLD()

		stopMLD(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stopMLD(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stopMLD(Arg2:string, Arg3:list)
			Args:
				args[0] is Arg2 (str): ID to associate each async action invocation
				args[1] is Arg3 (list(number)): List of indices into the group range grid An empty list indicates all instances in the plugin.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopMLD', payload=payload, response_object=None)

	def StopPeriodicGenQuery(self, *args, **kwargs):
		"""Executes the stopPeriodicGenQuery operation on the server.

		Stop Sending Periodic General Query

		stopPeriodicGenQuery(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stopPeriodicGenQuery', payload=payload, response_object=None)
